#
# Copyright 2009-2012 Red Hat, Inc.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
#
# Refer to the README and COPYING files for full details of the license
#
#
# Description:    Constants definitions for vdsm and utilities.

import os

#
# file ownership definitions
#
VDSM_USER = 'vdsm'
VDSM_GROUP = 'kvm'
DISKIMAGE_USER = 'vdsm'
DISKIMAGE_GROUP = 'qemu'
METADATA_USER = 'vdsm'
METADATA_GROUP = 'kvm'
QEMU_PROCESS_USER = 'qemu'

# This is the domain version translation list
# DO NOT CHANGE OLD VALUES ONLY APPEND
DOMAIN_VERSIONS = (0, 2, 3)
SUPPORTED_BLOCKSIZE = (512,)

# This contains the domains versions that this VDSM
# accepts currently its all of the version but in the
# future we might slice it (eg. tuple(DOMAIN_VERSION[1:]))
SUPPORTED_DOMAIN_VERSIONS = DOMAIN_VERSIONS

UUID_GLOB_PATTERN = '*-*-*-*-*'

MEGAB = 2 ** 20 # = 1024 ** 2 = 1 MiB

#
# Path definitions
#
P_LIBVIRT_VMCHANNELS = '/var/lib/libvirt/qemu/channels/'
P_VDSM = '/usr/share/vdsm/'
P_VDSM_HOOKS = '/usr/libexec/vdsm/hooks/'
P_VDSM_LIB = '/var/lib/vdsm/'
P_VDSM_RUN = '/var/run/vdsm/'
P_VDSM_CONF = '/etc/vdsm/'
P_VDSM_KEYS = '/etc/pki/vdsm/keys/'

P_VDSM_CLIENT_LOG = '/var/run/vdsm/client.log'
P_VDSM_LOG = '/var/log/vdsm'
P_VDSM_NODE_ID = '/etc/vdsm/vdsm.id'


#
# External programs (sorted, please keep in order).
#
EXT_ADDNETWORK = '/usr/share/vdsm/addNetwork'

EXT_BLKID = '/sbin/blkid'
EXT_BLOCKDEV = '/sbin/blockdev'
EXT_BRCTL = '/usr/sbin/brctl'

EXT_CAT = '/bin/cat'
EXT_CHOWN = '/bin/chown'
EXT_CP = '/bin/cp'

EXT_DD = '/bin/dd'
EXT_DELNETWORK = '/usr/share/vdsm/delNetwork'
EXT_DMIDECODE = '/usr/sbin/dmidecode'
EXT_DMSETUP = '/sbin/dmsetup'

EXT_EDITNETWORK = '/usr/share/vdsm/editNetwork'

EXT_FENCE_PREFIX = os.path.dirname('/usr/sbin/fence_ilo') + '/fence_'
EXT_FSCK = '/sbin/fsck'
EXT_FUSER = '/sbin/fuser'

EXT_GET_VM_PID = '/usr/share/vdsm/get-vm-pid'

EXT_IFCONFIG = '/sbin/ifconfig'
EXT_IFDOWN = '/sbin/ifdown'
EXT_IFUP = '/sbin/ifup'
EXT_IONICE = '/usr/bin/ionice'
EXT_ISCSIADM = '/sbin/iscsiadm'
EXT_TC = '/sbin/tc'

EXT_KILL = '/usr/bin/kill'

EXT_LSBLK = '/bin/lsblk'
EXT_LVM = '/sbin/lvm'

EXT_MKFS = '/sbin/mkfs'
EXT_MKFS_MSDOS = '/sbin/mkfs.msdos'
EXT_MKISOFS = '/usr/bin/mkisofs'
EXT_MK_SYSPREP_FLOPPY = '/usr/share/vdsm/mk_sysprep_floppy'
EXT_MOUNT = '/bin/mount'
EXT_MULTIPATH = '/sbin/multipath'
EXT_MV = '/bin/mv'

EXT_NICE = '/bin/nice'

EXT_PERSIST = '/usr/sbin/persist'
EXT_PGREP = '/usr/bin/pgrep'
EXT_PREPARE_VMCHANNEL = '/usr/share/vdsm/prepare-vmchannel'
EXT_PYTHON = '/usr/bin/python'

EXT_QEMUIMG = '/usr/bin/qemu-img'

EXT_REBOOT = '/sbin/reboot'
EXT_RPM = '/bin/rpm'
EXT_RSYNC = '/usr/bin/rsync'

EXT_SCSI_ID = '/sbin/scsi_id' #TBD !
EXT_SERVICE = '/sbin/service'
EXT_SETSID = '/usr/bin/setsid'
EXT_SH = '/bin/sh' # The shell path is invariable
EXT_SHOWMOUNT = '/usr/sbin/showmount'
EXT_SU = '/bin/su'
EXT_SUDO = '/usr/bin/sudo'

EXT_TAR = '/bin/tar'
EXT_TUNE2FS = '/sbin/tune2fs'

EXT_UDEVADM = '/sbin/udevadm'

EXT_UMOUNT = '/bin/umount'
EXT_UNPERSIST = '/usr/sbin/unpersist'

EXT_VCONFIG = '/sbin/vconfig'
EXT_VDSM_STORE_NET_CONFIG = '/usr/share/vdsm/vdsm-store-net-config'

EXT_WGET = '/usr/bin/wget'
EXT_WRITE_NET_CONFIG = '/usr/share/vdsm/write-net-config'

CMD_LOWPRIO = [EXT_NICE, '-n', '19', EXT_IONICE, '-c', '3']

#
# Storage constants
#
STRG_ISCSI_HOST = "iscsi_host/"
STRG_SCSI_HOST = "scsi_host/"
STRG_ISCSI_SESSION = "iscsi_session/"
STRG_MPATH_CONF = (
"\n\n"
"defaults {\n"
"    polling_interval        5\n"
"    getuid_callout          \"/sbin/scsi_id --whitelisted "
                                "--replace-whitespace --device=/dev/%n\"\n"
"    no_path_retry           fail\n"
"    user_friendly_names     no\n"
"    flush_on_last_del       yes\n"
"    fast_io_fail_tmo        5\n"
"    dev_loss_tmo            30\n"
"    max_fds                 4096\n"
"}\n"
"\n"
"devices {\n"
"device {\n"
"    vendor                  \"HITACHI\"\n"
"    product                 \"DF.*\"\n"
"    getuid_callout          \"/sbin/scsi_id --whitelisted "
                                "--replace-whitespace --device=/dev/%n\"\n"
"}\n"
"}"
)
